@@ -55,17 +55,29 @@ def main():
             )
         )
 
+    # If we updated any dependencies, then we need to install them
+    completed_process = subprocess.run(["npm", "install"], shell=True)
+    if completed_process.returncode != 0:
+        error("Failed to npm install.")
+
     if is_typescript_project():
-        # Check to make sure that the project compiles
-        completed_process = subprocess.run(["npx", "tsc"], shell=True)
-        if completed_process.returncode != 0:
-            error("Failed to build the project.")
+        compile_typescript()
 
     if args.skip_increment:
         version = get_version_from_package_json()
     else:
         version = increment_version_in_package_json()
 
+        # Build it again so that the new version number is included in the compiled code
+        if is_typescript_project():
+            compile_typescript()
+
+    if is_typescript_project():
+        # Check to make sure that the project compiles
+        completed_process = subprocess.run(["npx", "tsc"], shell=True)
+        if completed_process.returncode != 0:
+            error("Failed to build the project.")
+
     git_commit_if_changes(version)
 
     # Publish
@@ -163,6 +175,18 @@ def is_typescript_project():
     )
 
 
+def compile_typescript():
+    build_script_path = os.path.join(DIR, "build.sh")
+    if os.path.isfile(build_script_path):
+        completed_process = subprocess.run(["bash", build_script_path], shell=True)
+        if completed_process.returncode != 0:
+            error('Failed to run the "build.sh" script.')
+    else:
+        completed_process = subprocess.run(["npx", "tsc"], shell=True)
+        if completed_process.returncode != 0:
+            error('Failed to build the project with "npx tsc".')
+
+
 def git_commit_if_changes(version):
     # Check to see if this is a git repository
     completed_process = subprocess.run(
